/* Tabela MAPAPRXCOMEXP*/
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela MAPAPRXCOMEXP*/
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela MAPAPRXCOMEXP, utilizando a tabela Geral de Logs de Operaes */

IF EXISTS(SELECT *
          FROM SYSOBJECTS O, SYSUSERS U
          WHERE O.NAME = 'LOG_EXP_MAPAPRXCOMEXP' AND
                TYPE   = 'TR'              AND
                U.UID  = O.UID             AND
                U.NAME = USER)

DROP TRIGGER LOG_EXP_MAPAPRXCOMEXP
GO
CREATE TRIGGER LOG_EXP_MAPAPRXCOMEXP
ON MAPAPRXCOMEXP
FOR UPDATE,INSERT, DELETE
AS
BEGIN
  DECLARE @V_USUARIO             VARCHAR(40);
  DECLARE @V_TIPO                VARCHAR(1);
  DECLARE @V_TPMOVI              VARCHAR(1);
  DECLARE @V_ITPESQ              VARCHAR(40);
  DECLARE @V_DESC                VARCHAR(500);
  DECLARE @V_CDFILLOGOPER        VARCHAR(4);
  DECLARE @V_DSREMOTEADDR        VARCHAR(15);
  DECLARE @V_DSREMOTEHOST        VARCHAR(15);
  DECLARE @V_DSSERVERRDM         VARCHAR(20);
  DECLARE @V_DSSERVMETHOD        VARCHAR(30);
  DECLARE @V_DSREMOTEOPER        VARCHAR(12);
  DECLARE @V_DTOPER              DATETIME;

  DECLARE @V_CDVENDEDOR_NEW      VARCHAR(4);
  DECLARE @V_CDFILICOMIS_NEW     VARCHAR(4);
  DECLARE @V_NRMAPAPRXEXP_NEW     VARCHAR(10);
  DECLARE @V_CDFILIAL_NEW        VARCHAR(4);
  DECLARE @V_NRLANCTONF_NEW      VARCHAR(10);

  DECLARE @V_CDVENDEDOR_OLD      VARCHAR(4);
  DECLARE @V_CDFILICOMIS_OLD     VARCHAR(4);
  DECLARE @V_NRMAPAPRXEXP_OLD     VARCHAR(10);
  DECLARE @V_CDFILIAL_OLD        VARCHAR(4);
  DECLARE @V_NRLANCTONF_OLD      VARCHAR(10);

   SET @V_TIPO = '0';
   SET @V_DESC = '';
   SET @V_CDFILLOGOPER = '';
   SET @V_USUARIO = '-';

   DECLARE C_CURSOR_R CURSOR FOR
      SELECT
         'D' IDCOMANDO,
         NULL, NULL, NULL, NULL, NULL,
         CDVENDEDOR,
         CDFILICOMIS,
         NRMAPAPRXEXP,
         CDFILIAL,
         NRLANCTONF
      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)

      UNION ALL

      SELECT
         'U' IDCOMANDO,
         INSERTED.CDVENDEDOR,
         INSERTED.CDFILICOMIS,
         INSERTED.NRMAPAPRXEXP,
         INSERTED.CDFILIAL,
         INSERTED.NRLANCTONF,

         DELETED.CDVENDEDOR,
         DELETED.CDFILICOMIS,
         DELETED.NRMAPAPRXEXP,
         DELETED.CDFILIAL,
         DELETED.NRLANCTONF

      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDVENDEDOR   = DELETED.CDVENDEDOR  AND
         INSERTED.CDFILICOMIS  = DELETED.CDFILICOMIS AND
         INSERTED.NRMAPAPRXEXP = DELETED.NRMAPAPRXEXP

      UNION ALL

      SELECT
         'I' IDCOMANDO,
         INSERTED.CDVENDEDOR,
         INSERTED.CDFILICOMIS,
         INSERTED.NRMAPAPRXEXP,
         INSERTED.CDFILIAL,
         INSERTED.NRLANCTONF,

         NULL, NULL, NULL, NULL, NULL
      FROM
         INSERTED
      WHERE
         0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_CURSOR_R;
   FETCH NEXT FROM C_CURSOR_R INTO @V_TIPO,
                                   @V_CDVENDEDOR_NEW, @V_CDFILICOMIS_NEW, @V_NRMAPAPRXEXP_NEW, @V_CDFILIAL_NEW, @V_NRLANCTONF_NEW,
                                   
                                   @V_CDVENDEDOR_OLD, @V_CDFILICOMIS_OLD, @V_NRMAPAPRXEXP_OLD, @V_CDFILIAL_OLD, @V_NRLANCTONF_OLD;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      IF @V_TIPO = 'D' BEGIN

         IF @V_CDVENDEDOR_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Vendedor = ' + ISNULL(@V_CDVENDEDOR_OLD,'') + ' ';
         END;
         IF @V_CDFILICOMIS_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Filial = ' + ISNULL(@V_CDFILICOMIS_OLD,'') + ' ';
         END;
         IF @V_NRMAPAPRXEXP_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Nmero do detalhe = ' + ISNULL(@V_NRMAPAPRXEXP_OLD,'') + ' ';
         END;
         IF @V_CDFILIAL_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Filial da NF = ' + ISNULL(@V_CDFILIAL_OLD,'') + ' ';
         END;
         IF @V_NRLANCTONF_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Lanamento da NF = ' + ISNULL(@V_NRLANCTONF_OLD,'') + ' ';
         END;

         SET @V_TPMOVI = '3';
         SET @V_ITPESQ = @V_CDVENDEDOR_OLD + @V_CDFILICOMIS_OLD + @V_NRMAPAPRXEXP_OLD;
      END
      ELSE BEGIN
         IF @V_TIPO = 'U' BEGIN
             IF (@V_CDVENDEDOR_OLD      <> @V_CDVENDEDOR_NEW  ) OR
                (@V_CDFILICOMIS_OLD     <> @V_CDFILICOMIS_NEW ) OR
                (@V_NRMAPAPRXEXP_OLD    <> @V_NRMAPAPRXEXP_NEW) OR
                (@V_CDFILIAL_OLD        <> @V_CDFILIAL_NEW    ) OR
                (@V_NRLANCTONF_OLD      <> @V_NRLANCTONF_NEW  ) BEGIN

               SET @V_TPMOVI = '2';
               SET @V_ITPESQ = @V_CDVENDEDOR_OLD + @V_CDFILICOMIS_OLD + @V_NRMAPAPRXEXP_OLD;
            END;
         END
         ELSE BEGIN
            SET @V_TPMOVI = '1';
            SET @V_ITPESQ = @V_CDVENDEDOR_NEW + @V_CDFILICOMIS_NEW + @V_NRMAPAPRXEXP_NEW;
         END;

         IF ISNULL(@V_CDVENDEDOR_NEW, '!') <> ISNULL(@V_CDVENDEDOR_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + 'Vendedor = ' + @V_CDVENDEDOR_NEW;
         END;
         IF ISNULL(@V_CDFILICOMIS_NEW, '!') <> ISNULL(@V_CDFILICOMIS_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + 'Filial = ' + @V_CDFILICOMIS_NEW;
         END;
         IF ISNULL(@V_NRMAPAPRXEXP_NEW, '!') <> ISNULL(@V_NRMAPAPRXEXP_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + 'Nmero do detalhe = ' + @V_NRMAPAPRXEXP_NEW;
         END;
         IF ISNULL(@V_CDFILIAL_NEW, '!') <> ISNULL(@V_CDFILIAL_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + 'Filial da NF = ' + @V_CDFILIAL_NEW;
         END;
         IF ISNULL(@V_NRLANCTONF_NEW, '!') <> ISNULL(@V_NRLANCTONF_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + 'Lanamento da NF = ' + @V_NRLANCTONF_NEW;
         END;
      END;

      IF @V_TPMOVI <> '0' BEGIN
         EXEC NMUSUARIO  @V_USUARIO;
         EXEC WEBTUNNING @V_DSREMOTEADDR,
                         @V_DSREMOTEHOST,
                         @V_DSSERVERRDM,
                         @V_DSSERVMETHOD,
                         @V_DSREMOTEOPER;
         IF NOT @V_DESC IS NULL BEGIN

            SET @V_DTOPER = GETDATE();

            INSERT INTO LOGOPERA
               (NMTABELA,
                DTOPERACAO,
                NMRESPOPER,
                IDTIPOOPER,
                CDPESQITEM,
                DSOPERACAO,
                CDFILLOGOPER,
                DSRDMUSUOPER,
                DSENDUSUOPER,
                DSNMUSUOPER,
                DSMETUSUOPER,
                CDORESPOPER)
            VALUES
               ('MAPAPRXCOMEXP',
                @V_DTOPER,
                @V_USUARIO,
                @V_TPMOVI,
                @V_ITPESQ,
                SUBSTRING(@V_DESC,1,300),
                @V_CDFILLOGOPER,
                @V_DSSERVERRDM,
                @V_DSREMOTEADDR,
                @V_DSREMOTEHOST,
                @V_DSSERVMETHOD,
                @V_DSREMOTEOPER);

         END;
      END;
      FETCH NEXT FROM C_CURSOR_R INTO @V_TIPO,
                                      @V_CDVENDEDOR_NEW, @V_CDFILICOMIS_NEW, @V_NRMAPAPRXEXP_NEW, @V_CDFILIAL_NEW, @V_NRLANCTONF_NEW,
                                   
                                      @V_CDVENDEDOR_OLD, @V_CDFILICOMIS_OLD, @V_NRMAPAPRXEXP_OLD, @V_CDFILIAL_OLD, @V_NRLANCTONF_OLD;
   END;
   CLOSE C_CURSOR_R;
   DEALLOCATE C_CURSOR_R;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_EXP_MAPAPRXCOMEXP','5.85.XXX';
GO